from __future__ import absolute_import, division, print_function, unicode_literals


def agent(request):
    """
    A context processor that sets the template context variable ``agent`` to
    the value of ``request.agent``.
    """
    return {'agent': getattr(request, 'agent', None)}



from __future__ import absolute_import, division, print_function, unicode_literals

from random import randrange


def trust_agent(request, trust_days=None):
    """
    Mark the requesting agent as trusted for the currently logged-in user. This
    does nothing for anonymous users.

    :param request: The current request.
    :type request: :class:`~django.http.HttpRequest`
    :param float trust_days: The number of days to trust this agent. ``None``
        for no agent-specific limit.
    """
    from .models import Agent

    if request.user.is_authenticated:
        request.agent = Agent.trusted_agent(request.user, trust_days)


def trust_session(request):
    """
    Mark the requesting agent as trusted in the context of the current session;
    when the session ends, the agent's trust will be revoked. This replaces any
    agent trust that already exists. All expiration settings and future
    revocations still apply. This does nothing for anonymous users.

    :param request: The current request.
    :type request: :class:`~django.http.HttpRequest`
    """
    from .models import Agent, SESSION_TOKEN_KEY

    if request.user.is_authenticated:
        # We need a token to link this agent to the current session. It's
        # strictly internal, so it doesn't have to be cryptographically sound,
        # just probabalistically unique.
        token = randrange(2 ** 32)

        request.session[SESSION_TOKEN_KEY] = token
        request.agent = Agent.session_agent(request.user, token)


def revoke_agent(request):
    """
    Revoke trust in the requesting agent for the currently logged-in user.

    :param request: The current request.
    :type request: :class:`~django.http.HttpRequest`
    """
    from .models import Agent

    request.agent = Agent.untrusted_agent(request.user)


def revoke_other_agents(request):
    """
    Revoke trust in all of the logged-in user's agents other than the current
    one. This does nothing for anonymous users.

    :param request: The current request.
    :type request: :class:`~django.http.HttpRequest`
    """
    if request.user.is_authenticated:
        request.user.agentsettings.serial += 1
        request.user.agentsettings.save()

        request.agent._serial = request.user.agentsettings.serial



# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AgentSettings',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('trust_days', models.FloatField(default=None, help_text='The number of days a agent will remain trusted.', null=True, blank=True)),
                ('inactivity_days', models.FloatField(default=None, help_text="The number of days allowed between requests before a agent's trust is revoked.", null=True, blank=True)),
                ('serial', models.IntegerField(default=0, help_text='Increment this to revoke all previously trusted agents.')),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE)),
            ],
        ),
    ]



#!/usr/bin/env python

from setuptools import setup, find_packages


setup(
    name='django-agent-trust',
    version='0.4.0',
    description="A framework for managing agent trust, such as public vs. private computers.",
    author="Peter Sagerson",
    author_email='psagers@ignorare.net',
    url='https://github.com/django-otp/django-agent-trust',
    project_urls={
        "Documentation": 'https://django-agent-trust-official.readthedocs.io/',
        "Source": 'https://github.com/django-otp/django-agent-trust',
    },
    license='BSD',

    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    install_requires=[
        'django >= 1.11',
    ],

    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Topic :: Security',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
